@@ -6,4 +6,4 @@ from motorise import Agent
 class BaseSuite(unittest.TestCase):
     def setUp(self):
         self.agent = Agent()
-        self.url   = "http://www.google.com"
+        self.url   = "http://www.google.com.hk/"
